@@ -201,3 +201,7 @@ coerce_fct_na_explicit <- function(x){
 any_row_shade <- function(x){
   apply(data.frame(x), MARGIN = 1, FUN = function(x) any(grepl("^NA|^NA_", x)))
 }
+
+vecIsFALSE <- Vectorize(isFALSE)
+
+are_any_false <- function(x, ...) any(vecIsFALSE(x), ...)
