@@ -27,10 +27,19 @@ test_that("miss_var_span is a tbl", {
 })
 
 test_that("miss_var_span returns right dimensions",{
-  expect_equal(ncol(mvs), 5)
+  expect_equal(ncol(mvs), 6)
   expect_equal(nrow(mvs), 225)
-  expect_equal(ncol(mvs_g), 6)
+  expect_equal(ncol(mvs_g), 7)
   expect_equal(nrow(mvs_g), 230)
 })
 
+test_that("miss_var_span n_miss + n_complete returns the number of rows", {
+  test <- miss_var_span(pedestrian,
+                        var = hourly_counts,
+                        span_every = 4000)
+
+  totals <- sum(test$n_miss) + sum(test$n_complete)
+
+  expect_equal(totals, nrow(pedestrian))
+})
 
